@@ -9,15 +9,19 @@ class CheckQCException(Exception):
     pass
 
 
-class InstrumentTypeUnknown(CheckQCException):
+class ConfigurationError(CheckQCException):
     pass
 
 
-class RunModeUnknown(CheckQCException):
+class InstrumentTypeUnknown(ConfigurationError):
     pass
 
 
-class ReagentVersionUnknown(CheckQCException):
+class RunModeUnknown(ConfigurationError):
+    pass
+
+
+class ReagentVersionUnknown(ConfigurationError):
     pass
 
 
@@ -25,6 +29,10 @@ class RunInfoXMLNotFound(CheckQCException):
     pass
 
 
+class DemuxSummaryNotFound(CheckQCException):
+    pass
+
+
 class RunParametersNotFound(CheckQCException):
     pass
 
@@ -41,5 +49,13 @@ class ConfigurationError(CheckQCException):
     pass
 
 
-class ConfigEntryMissing(CheckQCException):
+class SamplesheetNotFound(CheckQCException):
+    pass
+
+
+class ConfigEntryMissing(ConfigurationError):
+    pass
+
+
+class RunfolderNotFoundError(CheckQCException):
     pass
